@@ -36,23 +36,6 @@ gboolean on_closeabout (GtkWidget *Awidget, GdkEventButton *Aevent, gpointer Ada
   return FALSE;
 }
 
-void on_togglecopiecd_clicked (GtkButton *Abutton, gpointer Adata)
-{
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(Abutton), TRUE); 
-}
-
-
-void on_togglecdaudio_clicked (GtkButton *Abutton, gpointer Adata)
-{
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(Abutton), TRUE); 
-}
-
-
-void on_togglecddata_clicked (GtkButton *Abutton, gpointer Adata)
-{
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(Abutton), TRUE);
-}
-
 /* callback appele pour l'ajout d'une piste audio */
 void _add_a_piste(gchar *Anom, GtkListStore *Aliststore, GHashTable *Ahash)
 {
@@ -342,7 +325,7 @@ void gtk_audio_removetrack(GtkWidget *Abtn, gpointer Adata)
     GtkTreePath *Lpath = gtk_tree_row_reference_get_path(Lnode->data);
     gtk_tree_model_get_iter(Ltreemodel, &Liter, Lpath);
  
-    gtk_tree_model_get(Ltreemodel, &Liter, 5, &Llennbr, -1);
+    gtk_tree_model_get(Ltreemodel, &Liter, 6, &Llennbr, -1);
     gtk_list_store_remove(GTK_LIST_STORE(Ltreemodel), &Liter);
 
     *Laudiolen-=Llennbr;
@@ -369,7 +352,7 @@ void remove_children_size(GtkTreeModel *Atreedata, GtkTreeIter *Aiter, guint32 *
 
   if (gtk_tree_model_iter_children(Atreedata, &Lcuriter, Aiter)) {
     do {
-      gtk_tree_model_get(Atreedata, &Lcuriter, 0, &Ltype, 5, &Lsizenbr, -1);
+      gtk_tree_model_get(Atreedata, &Lcuriter, 0, &Ltype, 6, &Lsizenbr, -1);
       *Acursize-=Lsizenbr;
 #if 0
       if (Ltype == TYPE_IMAGEBOOT) {
@@ -382,6 +365,32 @@ void remove_children_size(GtkTreeModel *Atreedata, GtkTreeIter *Aiter, guint32 *
   }
 }
 
+/* clique sur le popup pour la  mise a jour de la taille des icones utilisees */
+void gtk_display_updatesize(GtkWidget *Abtn, gpointer Adata)
+{
+  const gchar *Lname = glade_get_widget_name(Abtn);
+  GHashTable *Lhash = (GHashTable *) Adata;
+  gchar *Lsize = strrchr(Lname, '_');
+
+  g_assert(Lsize);
+
+  conf_store_value("iconsize", ++Lsize);
+
+  manage_top_menu(Lhash, MENU_UPDATE);
+}
+
+/* clique sur le popup pour l'affichage ou non de la status bar */
+void gtk_display_switchstatusbar(GtkWidget *Abtn, gpointer Adata)
+{
+  GHashTable *Lhash = (GHashTable *) Adata;
+  gboolean Ldispsb = conf_get_boolean("statusbar");
+
+  conf_store_value("statusbar", Ldispsb ? "0" : "1");
+
+  update_status_bar_display(Lhash);
+}
+
+
 /* enlever des fichiers a graver */
 void gtk_data_removefiles(GtkWidget *Abtn, gpointer Adata)
 {
@@ -418,7 +427,7 @@ void gtk_data_removefiles(GtkWidget *Abtn, gpointer Adata)
     if (Lpath) {
       gtk_tree_model_get_iter(Ltreedata, &Liter, Lpath);
 
-      gtk_tree_model_get(Ltreedata, &Liter, 5, &Lsizenbr, -1);
+      gtk_tree_model_get(Ltreedata, &Liter, 6, &Lsizenbr, -1);
 
       *Ldatasize-=Lsizenbr;
       g_assert((*Ldatasize) >= 0);
@@ -765,7 +774,7 @@ void on_selectgraveur(GtkWidget *Acombo, gpointer Adata)
   GtkTreeIter Liter;
   gboolean Lisimgiso = FALSE;
   const gchar *Lname = glade_get_widget_name(Acombo);
-  gchar *Laskname;
+  gchar *Laskname, *Lspeedname;
   gchar *Llecteur = NULL;
   guint Lident = 0;
   gint i;
@@ -780,10 +789,9 @@ void on_selectgraveur(GtkWidget *Acombo, gpointer Adata)
 
   Lisimgiso = !strcmp(Llecteur, "iso"); 
 
-  Laskname = g_strdup(Lname);
-  _SWAP_COMBO(Laskname, "speed");
-  Lvitesse = (GtkWidget *)g_hash_table_lookup(Lhash, Laskname);
-  g_free(Laskname);
+  Lspeedname = g_strdup(Lname);
+  _SWAP_COMBO(Lspeedname, "speed");
+  Lvitesse = (GtkWidget *)g_hash_table_lookup(Lhash, Lspeedname);
 
   Laskname = g_strdup(Lname);
   _SWAP_COMBO(Laskname, "table");
@@ -808,7 +816,7 @@ void on_selectgraveur(GtkWidget *Acombo, gpointer Adata)
   } 
 
   if (!Lisimgiso && GTK_IS_WIDGET(Lvitesse)) {
-    remplirecombovitesse(GTK_COMBO_BOX(Lvitesse), Llecteur); 
+    remplirecombovitesse(GTK_COMBO_BOX(Lvitesse), Llecteur, conf_get_string(Lspeedname)); 
   }
 
   for (i=0; ((Lobj = sc_hash_table_lookupv(Lhash, "%s_isotodisabled%d", Lname, i)) && GTK_IS_WIDGET(Lobj)); i++) {
@@ -821,6 +829,7 @@ void on_selectgraveur(GtkWidget *Acombo, gpointer Adata)
     gtk_widget_set_sensitive (Lobj, DRIVE_WRITER(Ldrive));
   }
 
+  g_free(Lspeedname);
   g_free(Llecteur);
 }
 
@@ -890,22 +899,22 @@ void confirm_erasecdrw(GtkWidget *Abtn, gpointer Adata)
 {
   GHashTable *Lhash = (GHashTable *)Adata;
   GtkWidget *Lwindow1 = GTK_WIDGET(g_hash_table_lookup(Lhash, "topwindow"));
-  GtkWidget *Lconfirm;
-  gint Lrep;
+  GHashTable *Ldialoghash = create_dialog_confirm_operation(Lwindow1, _("Do you really want to erase the CD-RW ?"),
+        ("_Fast blank disk when erasing CD-RW"), conf_get_boolean("fastblank"));
+  GtkWidget *Lconfirm = g_hash_table_lookup(Ldialoghash, "window");
 
   /* confirmation debut de l'operation */ 
-  Lconfirm = gtk_message_dialog_new(GTK_WINDOW(Lwindow1),
-                      GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION,
-                      GTK_BUTTONS_YES_NO,
-                      _("Do you really want to erase the CD-RW ?"));
-  Lrep = gtk_dialog_run(GTK_DIALOG(Lconfirm));
-
-  gtk_widget_destroy(Lconfirm);
-
-  if (Lrep == GTK_RESPONSE_YES) {
-    /* ok go ! */
+  if (gtk_dialog_run(GTK_DIALOG(Lconfirm)) == GTK_RESPONSE_YES) {
+    gboolean Lusefastblank = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(g_hash_table_lookup(Ldialoghash, "fastblank")));
+    gtk_widget_destroy(Lconfirm);
+    
+    g_hash_table_insert(Lhash, "usefastblank", &Lusefastblank);
     show_erasecdrwwindow(Lhash);
+    g_hash_table_remove(Lhash, "usefastblank");
+  } else {
+    gtk_widget_destroy(Lconfirm);
   }
+  g_hash_table_destroy(Ldialoghash);
 
 }
 
@@ -913,12 +922,16 @@ void confirm_erasecdrw(GtkWidget *Abtn, gpointer Adata)
 void confirm_burn (GtkWidget *Abtn, gpointer Adata)
 {
   GHashTable *Lhash = (GHashTable *)Adata;
-  gint Lrep;
+  GHashTable *Ldialoghash;
   GtkWidget *Lconfirm;
+  gint Lrep;
+  gboolean Luseautoblank = FALSE;
   const gchar *Lname;
   gchar *Ltxt = NULL;
   gchar *Ltitle = NULL;
   GtkWidget *Lwindow1 = GTK_WIDGET(g_hash_table_lookup(Lhash, "topwindow"));
+  GtkWidget *Ldevice;
+  gboolean Lwritercdrw;
 
   Lname = gtk_widget_get_name(Abtn);
 
@@ -941,6 +954,7 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
     }
     Ltxt = _("Do you really want to create an audio cd ?");
     Ltitle = _("Writing audio cd in progress...");
+    Ldevice = g_hash_table_lookup(Lhash, "dstaudiocombo");
   } else if (g_str_has_prefix(Lname, "btnburndata")) {
     GtkTreeIter Liter;
     GtkTreeModel *Ltreemodel = gtk_tree_view_get_model(GTK_TREE_VIEW(g_hash_table_lookup(Lhash, "LISTEDATA")));
@@ -957,29 +971,45 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
       gtk_dialog_run(GTK_DIALOG(Lconfirm));
       gtk_widget_destroy(Lconfirm);
       return;
-
     }
     Ltxt = _("Do you really want to create a data cd ?");
     Ltitle = _("Writing data cd in progress...");
+    Ldevice = g_hash_table_lookup(Lhash, "dstdatacombo");
   } else {
     /* copie de cd */
     Ltxt = _("Do you really want to start the copy ?");
     Ltitle = _("Copying in progress...");
+    Ldevice = g_hash_table_lookup(Lhash, "dstcopycombo");
   }
  
   /* confirmation debut de l'operation */ 
-  Lconfirm = gtk_message_dialog_new(GTK_WINDOW(Lwindow1),
-                      GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION,
-                      GTK_BUTTONS_YES_NO,
-                      Ltxt);
-  Lrep = gtk_dialog_run(GTK_DIALOG(Lconfirm));
+  /* on affiche l'option "effacer le CDRW que lorsque c'est un graveur qui le permet .. */
+  Lwritercdrw = DRIVE_CDRW_WRITER(get_drive_cmb(GTK_COMBO_BOX(Ldevice))) ? TRUE : FALSE;
+  Ldialoghash = create_dialog_confirm_operation(Lwindow1, Ltxt,
+       Lwritercdrw == TRUE ? _("Blank CD-RW before writing") : NULL, conf_get_boolean("autoblank"));
+  Lconfirm = g_hash_table_lookup(Ldialoghash, "window");
 
-  gtk_widget_destroy(Lconfirm);
+  Lrep = gtk_dialog_run(GTK_DIALOG(Lconfirm));
 
   if (Lrep == GTK_RESPONSE_YES) {
     /* ok go ! */
+    GtkCheckButton *Labcheck = GTK_CHECK_BUTTON(g_hash_table_lookup(Ldialoghash, "checkbox"));
+
+    g_assert(GTK_IS_WIDGET(Labcheck));
+    if (Lwritercdrw == TRUE) {
+      Luseautoblank = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Labcheck));
+    }
+
+    gtk_widget_destroy(Lconfirm);
+
+    g_hash_table_insert(Lhash, "useautoblank", &Luseautoblank);
     show_graverwindow(Lhash, (gchar *)Lname, Ltitle);
+    g_hash_table_remove(Lhash, "useautoblank");
+  } else {
+    gtk_widget_destroy(Lconfirm);
   }
+
+  g_hash_table_destroy(Ldialoghash);
 }
 
 /* popup ajouter des fichiers */
@@ -992,6 +1022,15 @@ void key_popupmenu_addfile(GtkWidget *Aliste, gpointer Adata) {
   gtk_menu_popup(Lpopupm, NULL, NULL, NULL, Aliste, 0, 0);
 }
 
+/* popup affichage */
+void view_popupmenu_display(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata) {
+  GtkMenu *Lpopupm = create_gtkpopupmenudisplay(Aliste, Adata);
+  gtk_menu_popup(Lpopupm, NULL, NULL, NULL, Aliste, Aevent->button, Aevent->time);
+}
+void key_popupmenu_display(GtkWidget *Aliste, gpointer Adata) {
+  GtkMenu *Lpopupm = create_gtkpopupmenudisplay(Aliste, Adata);
+  gtk_menu_popup(Lpopupm, NULL, NULL, NULL, Aliste, 0, 0);
+}
 
 /* popup ajouter des pistes audio */
 void view_popupmenu_addaudio(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata) {
@@ -1028,6 +1067,8 @@ gboolean gtk_do_eventbuttonpress(GtkWidget *Aliste, GdkEventButton *Aevent, gpoi
         view_popupmenu_addaudio(Aliste, Aevent, Adata);
       } else if (!strcmp(Lname, "periphdata")) {
         view_popupmenu_devices(Aliste, Aevent, Adata);
+      } else if (!strcmp(Lname, "topmenu")) {
+        view_popupmenu_display(Aliste, Aevent, Adata);
       }
       return TRUE;
     }
@@ -1072,43 +1113,6 @@ void gonextpage(GtkWidget *Antn, GtkNotebook *Anotebook)
   gtk_notebook_next_page(Anotebook);
 }
 
-/* clique sur l'un des boutons du menu de gauche */
-void changemenu(GtkToggleButton *Abutton, gpointer Adata)
-{
-  GHashTable *Lhash = (GHashTable *)Adata;
-  GtkNotebook *Lnotebook, *Lnotebookactif = g_hash_table_lookup(Lhash, "_menuactif");
-  const gchar *Lname = glade_get_widget_name(GTK_WIDGET(Abutton));
-  gchar *Ltmp;
-  gchar *Llstclick = g_hash_table_lookup(Lhash, "_lstclick");
-
-  if (!Lname || !*Lname) return;
-
-  Lnotebook = sc_hash_table_lookupv(Lhash, "body%s", Lname+strlen("btn"));
-
-  if (Llstclick && !strcmp(Llstclick, Lname)) {
-    if (gtk_toggle_button_get_active(Abutton)) return;
-
-    gtk_toggle_button_set_active(Abutton, TRUE);
-
-    return ;
-  }
-
-  Ltmp = Llstclick ? g_strdup(Llstclick) : NULL;
-  if (gtk_toggle_button_get_active(Abutton)) {
-    if (Llstclick) g_free(Llstclick);
-    Llstclick = g_strdup(Lname);
-    g_hash_table_replace(Lhash, "_lstclick", Llstclick);
-    gtk_widget_show(GTK_WIDGET(Lnotebook));
-    if (GTK_IS_WIDGET(Lnotebookactif)) gtk_widget_hide(GTK_WIDGET(Lnotebookactif));
-    g_hash_table_replace(Lhash, "_menuactif", Lnotebook);
-  }
- 
-  if (Ltmp) {
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g_hash_table_lookup(Lhash, Ltmp)), FALSE);
-    g_free(Ltmp);
-  }
-}
-
 /* callback pour verifier la longueur des textes buffer */
 void text_buffer_callback(GtkTextBuffer *Aobj, gpointer Adata)
 {
@@ -1135,12 +1139,29 @@ void text_buffer_callback(GtkTextBuffer *Aobj, gpointer Adata)
 void menu_active_panel(GtkWidget *Amenuitem, gpointer Adata)
 {
   GHashTable *Lhash = (GHashTable *)Adata;
+  GtkTreeView *Ltopmenu = GTK_TREE_VIEW(g_hash_table_lookup(Lhash, "topmenu"));
+  GtkTreeSelection *Lselection = gtk_tree_view_get_selection(Ltopmenu);
+  GtkTreeModel *Lmodel = gtk_tree_view_get_model(Ltopmenu);
+  GtkTreeIter Liter;
   const gchar *Lname = glade_get_widget_name(Amenuitem);
-  GtkToggleButton *Ltbtn = (GtkToggleButton *)sc_hash_table_lookupv(Lhash, "btn%s", Lname+strlen("menu"));
+  gchar *Lrequest = g_strdup_printf("body%s", Lname+strlen("menu"));
+  gchar *Lcuritem;
+  gchar Lcont = gtk_tree_model_get_iter_first(Lmodel, &Liter);
 
-  if (!GTK_IS_WIDGET(Ltbtn)) return;
-  
-  gtk_toggle_button_set_active(Ltbtn, TRUE);
+  while (Lcont == TRUE) {
+    gtk_tree_model_get(Lmodel, &Liter, 0, &Lcuritem, -1);
+
+    if (!strcmp(Lcuritem, Lrequest)) {
+      gtk_tree_selection_select_iter(Lselection, &Liter);
+      gtk_toggle_top_menu(Ltopmenu, Lhash);
+      
+      g_free(Lcuritem);
+      break;
+    }
+    g_free(Lcuritem);
+
+    Lcont = gtk_tree_model_iter_next(Lmodel, &Liter);
+  }
 }
 
 /* changement d'onglet */
@@ -1190,8 +1211,17 @@ void menu_active_proprietes(GtkWidget *Amenuitem, gpointer Adata)
   conf_store_value("overburn", _BOOLEAN_CONF(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Lptr))));
   Lptr = g_hash_table_lookup(Ldialoghash, "fastblank");
   conf_store_value("fastblank", _BOOLEAN_CONF(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Lptr))));
+  Lptr = g_hash_table_lookup(Ldialoghash, "autoblank");
+  conf_store_value("autoblank", _BOOLEAN_CONF(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Lptr))));
   Lptr = g_hash_table_lookup(Ldialoghash, "eject");
   conf_store_value("eject", _BOOLEAN_CONF(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Lptr))));
+  Lptr = g_hash_table_lookup(Ldialoghash, "statusbar");
+  conf_store_value("statusbar", _BOOLEAN_CONF(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Lptr))));
+  Lptr = g_hash_table_lookup(Ldialoghash, "iconsizelist");
+  conf_store_value("iconsize", get_combo_value((Lptr)));
+  Lptr = g_hash_table_lookup(Ldialoghash, "saveconfig");
+  conf_store_value("saveconfig", _BOOLEAN_CONF(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Lptr))));
+
 #if 0  
   Lptr = g_hash_table_lookup(Ldialoghash, "extended");
   conf_store_value("extended", _BOOLEAN_CONF(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Lptr))));
@@ -1216,12 +1246,12 @@ void menu_active_proprietes(GtkWidget *Amenuitem, gpointer Adata)
 
   /* mise a jour des listes contenant les lecteurs */
   update_combo_graveur(Lhash);
+  update_status_bar_display(Lhash);
+  manage_top_menu(Lhash, MENU_UPDATE);
 
   gtk_widget_destroy(Lwinproprietes);
 
-  _DEB("avant free");
   g_hash_table_destroy(Ldialoghash);
-  _DEB("apres free");
 }
 
 gboolean encours_callback(gpointer Adata)
@@ -1245,7 +1275,7 @@ void chercheprog(GtkWidget *Aobj, gpointer Adata)
   GtkWidget *Lwindow1 = g_hash_table_lookup(Lhash, "window");
 
   /* mise a jour de la configuration */
-  manage_new_config(Lhash, SEARCH_PROG, NULL);
+  manage_config(Lhash, SEARCH_PROG, NULL);
   clean_config();
 
   maj_proprietes_prog(Lhash);
@@ -1336,14 +1366,23 @@ void abort_encours(GtkWidget *Abtn, gpointer Adata)
   (*Labort) = TRUE;
   (*Lcont) = 1; /* on passe Lcont de 2 a 1 */
 }
+void delete_event_encours(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata)
+{
+  abort_encours(NULL, Adata);
+}
 
 /* on quitte l'application .. */
 void menu_quit(GtkWidget *Aobj1, gpointer Adata)
 {
   GHashTable *Lhash = (GHashTable *)Adata;
+  gint Loperation = UPDATE_SIZE + WRITE_CONFIG;
+
+  if (conf_get_boolean("saveconfig")==TRUE) {
+    Loperation+=UPDATE_SAVEONEXIT_VALUE;
+  }
 
   /* on sauve la position et taille de la fenetre */
-  manage_new_config(Lhash, UPDATE_SIZE + WRITE_CONFIG, NULL);
+  manage_config(Lhash, Loperation, NULL);
 
   gtk_main_quit();
 }
@@ -1604,8 +1643,14 @@ gboolean update_media_fields(GtkWidget *Awidget, gpointer Adata)
 void menu_start_new(GtkMenuItem *Amenuitem, gpointer Adata)
 {
   GHashTable *Lhash = (GHashTable *)Adata;
-  GtkNotebook *Lnotebookactif = g_hash_table_lookup(Lhash, "_menuactif");
-  const gchar *Lname = glade_get_widget_name(GTK_WIDGET(Lnotebookactif));
+  GtkTreeView *Ltopmenu = GTK_TREE_VIEW(g_hash_table_lookup(Lhash, "topmenu"));
+  gchar *Lname;
+  GtkTreeIter Liter;
+  GtkTreeSelection *Lselection = gtk_tree_view_get_selection(Ltopmenu);
+  GtkTreeModel *Ltreemodel = gtk_tree_view_get_model(Ltopmenu);
+
+  if (!gtk_tree_selection_get_selected(Lselection, &Ltreemodel, &Liter)) return;
+  gtk_tree_model_get(Ltreemodel, &Liter, 0, &Lname, -1);
 
   if (!strcmp(Lname, "bodycdaudio")) {
     /* on est sur l'onglet cd audio, on vide la liste */
@@ -1646,6 +1691,8 @@ void menu_start_new(GtkMenuItem *Amenuitem, gpointer Adata)
     }
 #endif
   }
+
+  g_free(Lname);
 }
 
 /* definir/enlever l'image de boot */
