@@ -69,11 +69,20 @@ static Tmyentry Gtypecddata[] = {
   { NULL }
 };
 
+static Tmyentry Gtypeicosize[] = {
+  { "16", N_("16x16 px"), FALSE },
+  { "24", N_("24x24 px"), FALSE },
+  { "32", N_("32x32 px"), FALSE },
+  { "48", N_("48x48 px"), FALSE },
+  { NULL }
+};
+
+/*
 static Tmyentry Gtypeunit[] = {
   { "kb", N_("kb"), TRUE },
   { "mb", N_("mb"), FALSE },
   { "gb", N_("gb"), FALSE },
-};
+};*/
 
 static Tmyentry Gmodburn[] = {
     { "dao", N_("Disk At Once - DAO (default)"), TRUE },
@@ -99,19 +108,17 @@ static Tmyentry Gformatcd[] = {
     { NULL }
   };
 
-void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident)
+void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident, gchar *Aselvalue)
 {
   GtkListStore *Ldata = GTK_LIST_STORE(gtk_combo_box_get_model(Acombo));
   gchar *Llabel, *Lident;  
   gint i;
   gint passe = 0;
   GtkTreeIter Liter;
-  gint Ldef = 0;
-  gboolean Lactive = FALSE;
   gint Lmaxspeed = MAX_SPEED;
-  const gchar *Ldefspeed = g_getenv("CDR_SPEED");
+  gboolean Lselok = FALSE;
 
-  if (Ldefspeed && *Ldefspeed) Ldef = atoi(Ldefspeed);
+  
 
   if (Alecident && *Alecident) {
     Tdriveinfo *Lundrive = find_drive(Alecident);
@@ -128,7 +135,14 @@ void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident)
     Lident = g_strdup_printf("%d", i);    
     gtk_list_store_append(Ldata, &Liter);
     gtk_list_store_set(Ldata, &Liter, 0, Lident, 1, Llabel, -1);
-    if (Ldef == i) { gtk_combo_box_set_active_iter(Acombo, &Liter); Lactive = TRUE; }
+
+    if (Aselvalue && *Aselvalue && Lselok == FALSE) {
+      if (!strcmp(Lident, Aselvalue)) {
+        gtk_combo_box_set_active_iter(Acombo, &Liter);
+        Lselok = TRUE;
+      }
+    }
+
     g_free(Llabel); g_free(Lident);
     
     if (i >= Lmaxspeed) break;
@@ -136,15 +150,17 @@ void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident)
 
   gtk_list_store_append(Ldata, &Liter);
   gtk_list_store_set(Ldata, &Liter, 0, "0", 1, _("Full speed"), -1);
-  if (Lactive == FALSE) gtk_combo_box_set_active_iter(Acombo, &Liter);
+  
+  if (Lselok == FALSE) gtk_combo_box_set_active_iter(Acombo, &Liter);
 }
 
-void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gboolean Adoinit)
+void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gboolean Adoinit, gchar *Aselvalue)
 {
   GtkListStore *Ldata;
   gchar *Lident;
   Tmyentry *Lcurentry;
   GtkTreeIter Liter;
+  gboolean Lselok = FALSE;
 
   if (Adoinit == FALSE) {
     Ldata = GTK_LIST_STORE(gtk_combo_box_get_model(Acombo));
@@ -167,19 +183,34 @@ void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gbo
     Lident = g_strdup_printf("%s%s", Abasename, Lcurentry->basecode);
     gtk_list_store_append(Ldata, &Liter);
     gtk_list_store_set(Ldata, &Liter, 0, Lident, 1, _(Lcurentry->label), -1); 
+
+    if (!Aselvalue || !*Aselvalue) {
+      if (Lcurentry->defaut == TRUE) {
+        gtk_combo_box_set_active_iter(Acombo, &Liter);
+        Lselok = TRUE;
+      }
+    } else {
+      if (!strcmp(Aselvalue, Lident)) { 
+        gtk_combo_box_set_active_iter(Acombo, &Liter);
+        Lselok = TRUE;
+      }
+    }
     g_free(Lident);
-    if (Lcurentry->defaut == TRUE) gtk_combo_box_set_active_iter(Acombo, &Liter);
   }
+
+  /* si pas de selection alors on met le premier par defaut */
+  if (Lselok == FALSE) gtk_combo_box_set_active(Acombo, 0);
 }
 
-void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi)
+void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi, gchar *Aselvalue)
 {
   GtkListStore *Ldata = GTK_LIST_STORE(gtk_combo_box_get_model(Acombo));
-  gboolean Lpremier = FALSE;
   GtkTreeIter Liter;
   GSList *Lcur;
   Tdriveinfo *Ldrive;
   gint i;
+  gboolean Lselok = FALSE;
+  gchar *Lcurdrive;
 
   gtk_list_store_clear(Ldata);
  
@@ -189,19 +220,31 @@ void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi)
     
     gtk_list_store_append(Ldata, &Liter);
 
-    gtk_list_store_set(Ldata, &Liter, 0, (gchar *)g_slist_nth_data(Ldrive->dev, Ldrive->actuperiph), 1, 
+    Lcurdrive =g_slist_nth_data(Ldrive->dev, Ldrive->actuperiph);
+    
+    gtk_list_store_set(Ldata, &Liter, 0, Lcurdrive, 1, 
       DRIVE_ICONE(Ldrive), 2, Ldrive->name, 3, i, -1);
     
-    if (Lpremier == FALSE) {      
-      Lpremier = TRUE;
-      gtk_combo_box_set_active_iter(Acombo, &Liter);
+    if (Aselvalue && *Aselvalue && Lselok==FALSE) {
+      if (!strcmp(Aselvalue, Lcurdrive)) { 
+        gtk_combo_box_set_active_iter(Acombo, &Liter); 
+        Lselok = TRUE;
+      }
     }
   }
   
-  if (Aquoi & ISO) {    
+  if (Aquoi & ISO) { 
     gtk_list_store_append(Ldata, &Liter);
-    gtk_list_store_set(Ldata, &Liter, 0, "iso", 1, GISOpetiteIcone, 2, _("ISO file..."), 3, 0, -1);
-  }  
+    gtk_list_store_set(Ldata, &Liter, 0, "iso", 1, GISOpetiteIcone, 2, _("ISO file..."), 3, -1, -1);
+
+    if (Aselvalue && Lselok==FALSE && !strcmp(Aselvalue, "iso")) {
+      gtk_combo_box_set_active_iter(Acombo, &Liter); 
+      Lselok = TRUE;
+    }
+  }
+
+/* si pas de selection alors on met le premier par defaut */
+  if (Lselok == FALSE) gtk_combo_box_set_active(Acombo, 0);
 }
 
 void remplirelistegraveur(GtkTreeView *Aliste)
@@ -288,6 +331,31 @@ GtkMenu *create_gtkpopupmenuaudio(GtkWidget *Aliste, GHashTable *Ahash)
   return Lmenu;
 }
 
+/* creation popup "affichage" */
+GtkMenu *create_gtkpopupmenudisplay(GtkWidget *Aliste, GHashTable *Ahash)
+{
+  GtkMenu *Lmenu = GTK_MENU(g_hash_table_lookup(Ahash, "popupdisplay"));
+  gboolean Ldispsb = conf_get_boolean("statusbar");
+  GtkWidget *Litem, *Litem2;
+  
+
+  Litem = g_hash_table_lookup(Ahash, "popupdisp_showstatusbar");
+  Litem2 = g_hash_table_lookup(Ahash, "popupdisp_hidestatusbar");
+  if (Ldispsb) {
+    gtk_widget_hide(Litem);
+    gtk_widget_show(Litem2);
+  } else {
+    gtk_widget_show(Litem);
+    gtk_widget_hide(Litem2);
+  }
+
+  Litem = sc_hash_table_lookupv(Ahash, "popupdisp_iconsize_%s", conf_get_string("iconsize"));
+  if (GTK_IS_WIDGET(Litem)) gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(Litem), TRUE);
+  
+  return Lmenu;
+}
+
+/* creation popup "data" */
 GtkMenu *create_gtkpopupmenudata(GtkWidget *Aliste, GHashTable *Ahash)
 {
   GtkMenu *Lmenu = GTK_MENU(g_hash_table_lookup(Ahash, "popupdata"));
@@ -460,6 +528,22 @@ void prepare_popups(GladeXML *Axml, GHashTable *Ahash)
       "activate", G_CALLBACK(gtk_def_imageboot), Ahash);
 #endif
 
+  /* popup affichage */
+  glade_to_hash(Axml, Ahash, "popupdisplay");
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_iconsize_48")),
+      "activate", G_CALLBACK(gtk_display_updatesize), Ahash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_iconsize_32")),
+      "activate", G_CALLBACK(gtk_display_updatesize), Ahash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_iconsize_24")),
+      "activate", G_CALLBACK(gtk_display_updatesize), Ahash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_iconsize_16")),
+      "activate", G_CALLBACK(gtk_display_updatesize), Ahash);
+
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_showstatusbar")),
+      "activate", G_CALLBACK(gtk_display_switchstatusbar), Ahash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_hidestatusbar")),
+      "activate", G_CALLBACK(gtk_display_switchstatusbar), Ahash);
+
 }
 
 GtkAlignment *new_seliso(gchar *Aname, GtkWidget *Aparent)
@@ -516,10 +600,9 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   GtkWidget *Lwindow;
   GtkNotebook *Lbodycdaudio, *Lbodycddata, *Lbodycdcopy, *Lbodycdother;
   GtkHBox *Lmainbody;
-  GtkToggleButton *Ltogbtnaudio, *Ltogbtncopy, *Ltogbtnother, *Ltogbtndata;
   GtkComboBox *Lcombo;
   GtkButton *Lbtnerasecdrw;
-  GtkTreeView *Ltreeaudio, *Ltreedata;
+  GtkTreeView *Ltreeaudio, *Ltreedata, *Ltopmenu;
   GHashTable *Lhash = _hash();
 
   if (!Lxml) {
@@ -543,22 +626,20 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   gtk_widget_reparent(GTK_WIDGET(Lbodycdcopy), GTK_WIDGET(Lmainbody));
   Lbodycdother = GTK_NOTEBOOK(glade_to_hash(Lxml, Lhash, "bodycdother"));
   gtk_widget_reparent(GTK_WIDGET(Lbodycdother), GTK_WIDGET(Lmainbody));
+  g_hash_table_replace(Lhash, "_lstclicked", Lbodycdaudio);
 
   /* mise a jour des label lorsque l'on change d'onglet dans la partie "graver un cd de donnee" */
   g_signal_connect(G_OBJECT(Lbodycddata), "switch-page", G_CALLBACK(switchpage), Lhash);
 
   /* bouttons barre de gauche */
-  Ltogbtndata = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "btncddata"));
-  g_signal_connect(G_OBJECT(Ltogbtndata), "toggled", G_CALLBACK(changemenu), Lhash);
-  Ltogbtncopy = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "btncdcopy"));
-  g_signal_connect(G_OBJECT(Ltogbtncopy), "toggled", G_CALLBACK(changemenu), Lhash);
-  Ltogbtnother = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "btncdother"));
-  g_signal_connect(G_OBJECT(Ltogbtnother), "toggled", G_CALLBACK(changemenu), Lhash);
-  Ltogbtnaudio = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "btncdaudio"));
-  g_signal_connect(G_OBJECT(Ltogbtnaudio), "toggled", G_CALLBACK(changemenu), Lhash);
+  Ltopmenu = GTK_TREE_VIEW(glade_to_hash(Lxml, Lhash, "topmenu"));
+  glade_to_hash(Lxml, Lhash, "statusbar");
+
+  manage_top_menu(Lhash, MENU_NEW);
+  update_status_bar_display(Lhash);
+  g_signal_connect(G_OBJECT(Ltopmenu), "button-press-event", G_CALLBACK(gtk_do_eventbuttonpress), Lhash);
+  g_signal_connect(G_OBJECT(Ltopmenu), "popup-menu", G_CALLBACK(key_popupmenu_display), Lhash);
 
-  /* activation onglet "cd audio" par defaut */
-  gtk_toggle_button_set_active(Ltogbtnaudio, TRUE);
 
   /* signaux sur le menu */
   g_signal_connect(G_OBJECT(glade_xml_get_widget(Lxml, "menustartnew")), "activate",
@@ -588,7 +669,7 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   glade_to_hash(Lxml, Lhash, "dstdatatable");
 
   /* onglet graver un cd audio */
-  glade_to_hash_list(Lxml, Lhash, "audiosimul", "audionotfix", "nbrcdaudio", NULL);
+  glade_to_hash_list(Lxml, Lhash, "audiosimul", "audionotfix", "audiodao", "nbrcdaudio", NULL);
 
   /* onglet graver un cd de donnee */
   glade_to_hash_list(Lxml, Lhash, "datavoli", "datapubl", "dataprep", "databibl", "datacopy", "dataabst",
@@ -617,15 +698,18 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
 
 
   /* on rempli les autres combo */
-  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "dataformat")), "", Gformatcd, TRUE);
-  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "datamodburn")), "", Gmodburn, TRUE);
-  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "dataisolevel")), "", Gisolevel, TRUE);
+  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "dataformat")), "", Gformatcd,
+      TRUE, conf_get_string("dataformat"));
+  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "datamodburn")), "", Gmodburn,
+      TRUE, conf_get_string("datamodburn"));
+  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "dataisolevel")), "", Gisolevel,
+      TRUE, conf_get_string("dataisolevel"));
   Lcombo = GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "listeremplidata"));
-  remplirecombo(Lcombo, "", Gtypecddata, TRUE); 
+  remplirecombo(Lcombo, "", Gtypecddata, TRUE, conf_get_string("listeremplidata")); 
   g_signal_connect(G_OBJECT(Lcombo), "changed", G_CALLBACK(change_remplissage), Lhash);
 
   Lcombo = GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "listerempliaudio"));
-  remplirecombo(Lcombo, "", Gtypecdaudio, TRUE);
+  remplirecombo(Lcombo, "", Gtypecdaudio, TRUE, conf_get_string("listerempliaudio"));
   g_signal_connect(G_OBJECT(Lcombo), "changed", G_CALLBACK(change_remplissage), Lhash);
  
   /* boutons "page suivante" */
@@ -689,6 +773,9 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   /* on restaure la taille et la position que la fenetre avait lors de la derniere utilisation */ 
   restore_main_window_pos(Lwindow); 
 
+  /* on restaure les dernieres valeurs utilisees pour certains champs */
+  restore_last_used_values(Lhash);
+  
   gtk_widget_show(Lwindow);
 
   return Lwindow;
@@ -702,21 +789,16 @@ void update_combo_graveur(GHashTable *Ahash)
   GtkComboBox *Ldstdatacombo = GTK_COMBO_BOX(g_hash_table_lookup(Ahash, "dstdatacombo"));
   GtkComboBox *Ldstaudiocombo = GTK_COMBO_BOX(g_hash_table_lookup(Ahash, "dstaudiocombo"));
   GtkComboBox *Ldstothercombo = GTK_COMBO_BOX(g_hash_table_lookup(Ahash, "dstothercombo"));
-  
-  remplirecombograveur(Lsrccopycombo, ALL + ISO);
-  on_selectgraveur(GTK_WIDGET(Lsrccopycombo), Ahash);
-  
-  remplirecombograveur(Ldstcopycombo, GRAVEUR_ONLY + ISO);
-  on_selectgraveur(GTK_WIDGET(Ldstcopycombo), Ahash);
-  
-  remplirecombograveur(Ldstdatacombo, GRAVEUR_ONLY + ISO);
-  on_selectgraveur(GTK_WIDGET(Ldstdatacombo), Ahash);
-  
-  remplirecombograveur(Ldstaudiocombo, GRAVEUR_ONLY);
-  on_selectgraveur(GTK_WIDGET(Ldstaudiocombo), Ahash);
 
-  remplirecombograveur(Ldstothercombo, GRAVEUR_ONLY);
-  on_selectgraveur(GTK_WIDGET(Ldstothercombo), Ahash);
+  remplirecombograveur(Lsrccopycombo, ALL + ISO, conf_get_string("srccopycombo"));
+  
+  remplirecombograveur(Ldstcopycombo, GRAVEUR_ONLY + ISO, conf_get_string("dstcopycombo"));
+  
+  remplirecombograveur(Ldstdatacombo, GRAVEUR_ONLY + ISO, conf_get_string("dstdatacombo"));
+  
+  remplirecombograveur(Ldstaudiocombo, GRAVEUR_ONLY, conf_get_string("dstaudiocombo"));
+
+  remplirecombograveur(Ldstothercombo, GRAVEUR_ONLY, conf_get_string("dstothercombo"));
 }
 
 GtkWidget* create_fileselection1 (GtkWindow *AParent, GtkFileChooserAction AType)
@@ -950,7 +1032,7 @@ void about_graveman (void)
 
   Llabelversion = GTK_LABEL(glade_xml_get_widget(Lxml, "version"));
 
-  Ltmp = g_strdup_printf(_("version %s"), VERSION);
+  Ltmp = g_strdup_printf(_("version %s - http://www.nongnu.org/graveman"), VERSION);
   gtk_label_set_label(Llabelversion, Ltmp);
   g_free(Ltmp);
 
@@ -976,6 +1058,7 @@ void show_graverwindow (GHashTable *Ahash, gchar *Aaction, gchar *Atitle)
   gboolean Lbackvalue = FALSE;
   gint Lcont = 1;
   GtkWidget *Lstatusbox = NULL;
+  GtkWidget *Lparent = GTK_WIDGET(g_hash_table_lookup(Ahash, "topwindow"));
   GError *Lerror = NULL;
 
   if (!Lxml) {
@@ -983,6 +1066,7 @@ void show_graverwindow (GHashTable *Ahash, gchar *Aaction, gchar *Atitle)
   }
 
   Lwindowburn = glade_xml_get_widget(Lxml, "window_burn"); 
+  gtk_window_set_transient_for(GTK_WINDOW(Lwindowburn), GTK_WINDOW(Lparent));
 
   /* titres avancement */
   Ltitle = GTK_LABEL(glade_to_hash(Lxml, Ahash, "gravetitle"));
@@ -1133,8 +1217,101 @@ void prepare_disable_when_notcdrw(GHashTable *Ahash, gchar *Abasename, const gch
   va_end(Largs);
 } 
 
+void gtk_toggle_top_menu(GtkTreeView *Atopmenu, gpointer Adata)
+{
+  GHashTable *Lhash = (GHashTable *)Adata;
+  GtkTreeModel *Ltreemodel = gtk_tree_view_get_model(Atopmenu);
+  GtkTreeIter Liter;
+  gchar *Lident;
+  GtkNotebook *Llstclick = g_hash_table_lookup(Lhash, "_lstclicked"); /* dernier element ayant eu le focus */
+  GtkNotebook *Lnewclick;
+  GtkTreeSelection *Lselection = gtk_tree_view_get_selection(Atopmenu);
 
-/*void prepare_combobox_graveur(GtkComboBox *Acombobox, GHashTable *Ahash)*/
+  if (!gtk_tree_selection_get_selected(Lselection, &Ltreemodel, &Liter)) return;
+
+  gtk_tree_model_get(Ltreemodel, &Liter, 0, &Lident, -1);
+
+  Lnewclick = g_hash_table_lookup(Lhash, Lident);
+  if (GTK_IS_NOTEBOOK(Lnewclick)) {
+  
+    if (GTK_IS_NOTEBOOK(Llstclick)) {
+      gtk_widget_hide(GTK_WIDGET(Llstclick));
+    }
+    g_hash_table_replace(Lhash, "_lstclicked", Lnewclick);
+
+    gtk_widget_show(GTK_WIDGET(Lnewclick));
+  }
+    
+  g_free(Lident);
+}
+
+/* status bar */
+void update_status_bar_display(GHashTable *Ahash)
+{
+  gboolean Ldispsb = conf_get_boolean("statusbar");
+  GtkWidget *Ldisp = g_hash_table_lookup(Ahash, "statusbar");
+
+  if (Ldispsb) {
+    gtk_widget_show(Ldisp);
+  } else {
+    gtk_widget_hide(Ldisp);
+  }
+}
+
+/* bar menu de gauche */
+void manage_top_menu(GHashTable *Ahash, gint Aaction)
+{
+  GtkListStore *Lmodel;
+  GtkTreeView *Ltopmenu = g_hash_table_lookup(Ahash, "topmenu");
+  GtkTreeSelection *Lselection = gtk_tree_view_get_selection(Ltopmenu);
+  GtkTreeIter Liter;
+  GtkCellRenderer *Lcellrender;
+  GtkTreeViewColumn *Lcell;
+
+  if (Aaction == MENU_NEW) {
+    Lmodel = gtk_list_store_new(3, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_STRING);
+    gtk_tree_selection_set_mode(Lselection, GTK_SELECTION_BROWSE);
+    gtk_tree_view_set_model(Ltopmenu, GTK_TREE_MODEL(Lmodel));
+
+    /* creation colonnes */
+    Lcellrender = gtk_cell_renderer_pixbuf_new();
+    Lcell = gtk_tree_view_column_new_with_attributes("", Lcellrender, "pixbuf", 1, NULL);
+     gtk_tree_view_append_column(GTK_TREE_VIEW(Ltopmenu), Lcell);
+	
+    Lcellrender = gtk_cell_renderer_pixbuf_new();
+    Lcellrender = gtk_cell_renderer_text_new();
+    Lcell = gtk_tree_view_column_new_with_attributes("", Lcellrender, "text", 2, NULL);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(Ltopmenu), Lcell);
+    Lcellrender = gtk_cell_renderer_pixbuf_new();
+
+    g_signal_connect(G_OBJECT(Ltopmenu), "cursor-changed", G_CALLBACK(gtk_toggle_top_menu), Ahash); 
+  } else {
+    Lmodel = GTK_LIST_STORE(gtk_tree_view_get_model(Ltopmenu));
+    gtk_list_store_clear(Lmodel);
+  }
+
+  /* les icones en elles meme */
+  prepare_menu_images(Ahash);
+
+  gtk_list_store_append(Lmodel, &Liter);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdaudio", 1, GMenuAudio, 2, _("Audio CD"), -1);
+  gtk_tree_selection_select_iter(Lselection, &Liter);
+  gtk_toggle_top_menu(Ltopmenu, Ahash);
+
+  gtk_list_store_append(Lmodel, &Liter);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycddata", 1, GMenuData, 2, _("Data CD"), -1);
+
+  gtk_list_store_append(Lmodel, &Liter);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdcopy", 1, GMenuCopy, 2, _("Duplicate CD"), -1);
+
+  gtk_list_store_append(Lmodel, &Liter);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdother", 1, GMenuOther, 2, _("Other operations"), -1);
+ 
+  gtk_tree_view_columns_autosize(Ltopmenu); 
+}
+
+    
+/* preparation du combo contenant la liste du peripherique a utiliser */
 void prepare_combobox_graveur(GladeXML *Axml, GHashTable *Ahash, gchar *Abasename)
 {
   GtkComboBox *Lcombobox = GTK_COMBO_BOX(glade_to_hashv(Axml, Ahash, "%scombo", Abasename));
@@ -1297,6 +1474,41 @@ void prepare_listedata(GtkTreeView *Atreedata)
   gtk_tree_store_set(Lmodel, &Liter, 0, TYPE_CD, 1, GCDpetiteIcone, 2, _("New CD"), 3, "", 4, "", 5, "", 6, 0, -1);
 }
 
+/* fenetre de confirmation avec une checkbox */
+GHashTable *create_dialog_confirm_operation (GtkWidget *Aparent,
+    gchar *Alabel, gchar *Acheckboxlbl, gboolean Acheckboxstatus)
+{
+  gchar *Ltemplate = PACKAGE_DATA_DIR "/" PACKAGE "/dialog_confirm_operation.glade";
+  GladeXML *Lxml = glade_xml_new(Ltemplate, NULL,NULL);
+  GtkWidget *Ldialog;
+  GtkLabel *Llabel;
+  GtkToggleButton *Ltoggleoption;
+  GHashTable *Lhash = _hash();
+
+  if (!Lxml) {
+    g_error("Cannot load '%s': %s\n", Ltemplate, g_strerror(errno));
+  }
+
+  Ldialog = glade_xml_get_widget(Lxml, "dialog_confirm_operation");
+  gtk_window_set_transient_for(GTK_WINDOW(Ldialog), GTK_WINDOW(Aparent));
+  g_hash_table_insert(Lhash, "window", Ldialog);
+
+  /* titre */
+  Llabel = GTK_LABEL(glade_to_hash(Lxml, Lhash, "label"));
+  gtk_label_set_text(Llabel, Alabel);
+  
+  /* effacer les cdrw en mode fast ? */
+  Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "checkbox"));
+  if (Acheckboxlbl) {
+    gtk_toggle_button_set_active(Ltoggleoption, Acheckboxstatus);
+    gtk_button_set_label(GTK_BUTTON(Ltoggleoption), Acheckboxlbl);
+  } else {
+    gtk_widget_hide(GTK_WIDGET(Ltoggleoption));
+  }
+
+  return Lhash;
+}
+
 /* fenetre proprietes */
 GHashTable *create_dialog_proprietes (GtkWidget *Aparent)
 {
@@ -1323,6 +1535,10 @@ GHashTable *create_dialog_proprietes (GtkWidget *Aparent)
   Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "overburn"));
   gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("overburn"));
 
+  /* effacer les cdrw avant ecriture */
+  Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "autoblank"));
+  gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("autoblank"));
+
   /* effacer les cdrw en mode fast ? */
   Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "fastblank"));
   gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("fastblank"));
@@ -1331,6 +1547,18 @@ GHashTable *create_dialog_proprietes (GtkWidget *Aparent)
   Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "eject"));
   gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("eject"));
 
+  /* afficher le status bar ? */
+  Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "statusbar"));
+  gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("statusbar"));
+  
+  /* combo taille des icones */
+  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "iconsizelist")), "", 
+      Gtypeicosize, TRUE, conf_get_string("iconsize"));
+
+  /* sauver les donnees lorsque l'on quitte ? */
+  Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "saveconfig"));
+  gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("saveconfig"));
+
   /* fonctions etendues ? */
 #if 0  
   Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "extended"));
@@ -1472,10 +1700,12 @@ void show_erasecdrwwindow(GHashTable *Ahash)
   g_hash_table_insert(Lerasecdhash, "labelava", Llabel);
   g_hash_table_insert(Lerasecdhash, "progress", Lprogressbar);
   g_hash_table_insert(Lerasecdhash, "dstothercombo", g_hash_table_lookup(Ahash, "dstothercombo"));
+  g_hash_table_insert(Lerasecdhash, "usefastblank", g_hash_table_lookup(Ahash, "usefastblank"));
 
   /* bouton annuler */
   Lcancel = glade_xml_get_widget(Lxmlencours, "cancelbtn");
-  g_signal_connect(G_OBJECT(Lcancel), "clicked", G_CALLBACK(abort_encours), (GtkWidget *)Lerasecdhash);
+  g_signal_connect(G_OBJECT(Lcancel), "clicked", G_CALLBACK(abort_encours), Lerasecdhash);
+  g_signal_connect(G_OBJECT(Lwin), "delete-event", G_CALLBACK(delete_event_encours), Lerasecdhash);
 
   gtk_widget_show(Lwin);
   g_timeout_add(500, encours_callback, Lerasecdhash);
@@ -1539,7 +1769,8 @@ void show_fixcdwindow(GHashTable *Ahash)
 
   /* bouton annuler */
   Lcancel = glade_xml_get_widget(Lxmlencours, "cancelbtn");
-  g_signal_connect(G_OBJECT(Lcancel), "clicked", G_CALLBACK(abort_encours), (GtkWidget *)Lfixcdhash);
+  g_signal_connect(G_OBJECT(Lcancel), "clicked", G_CALLBACK(abort_encours), Lfixcdhash);
+  g_signal_connect(G_OBJECT(Lwin), "delete-event", G_CALLBACK(delete_event_encours), Lfixcdhash);
 
   gtk_widget_show(Lwin);
   g_timeout_add(500, encours_callback, Lfixcdhash);
