@@ -51,6 +51,14 @@ gboolean graveman_init(gint Aargc, gchar *Aargv[]) {
           _("no")
 #endif
           );
+      g_printf("%s: %s\n", _("Compiled with linux-ide devices support"),
+#ifdef LINUX_IDE
+          _("yes")
+#else
+          _("no")
+#endif
+          );
+
       g_printf("%s %s\n", _("Compiled"), 
 #ifdef DEBUG
           _("with debug support")
@@ -114,26 +122,15 @@ gint main (gint Aargc, gchar *Aargv[])
   config_init();
   if (!is_config_valide()) {
     GHashTable *Lhash = _hash();
-    manage_new_config(Lhash, SEARCH_LECTEUR + SEARCH_PROG + WRITE_CONFIG, &Lerror);
+    manage_config(Lhash, SEARCH_LECTEUR + SEARCH_PROG + WRITE_CONFIG, &Lerror);
     g_free(Lhash);
     welcome_to_graveman();
   } else {
     read_config(&Lerror);
   }
 
-  GDirIcone = create_pixbuf("folder5-petit.png");
-  GFileIcone = create_pixbuf("stock_new.png");
-  GFileImage = create_pixbuf("file_image.png");
-  GCDIcone = create_pixbuf("gnome-dev-cdrom.png");
-  GAudioIcone = create_pixbuf("gnome-dev-cdrom-audio-24.png");
-  GCDRWIcone = create_pixbuf("i-cdrom.png");
-  GCDRWpetiteIcone = create_pixbuf("petitcdrw.png");
-  GCDpetiteIcone = create_pixbuf("petitcd.png");
-  GISOpetiteIcone = create_pixbuf("petitiso.png");
-  GpetiteGraver = create_pixbuf("graver-petite.png");
-  GGraver = create_pixbuf("graver.png");
-  GEraseCdrw = create_pixbuf("erase-cdrw.png");
-
+  load_all_images();
+  
   Lwindow1 = manage_main_window (&Laudiolen, &Laudiomaxlen, &Ldatasize, &Ldatamaxsize);  
   gtk_main ();
   /* on libere avant de quitter */
@@ -142,18 +139,8 @@ gint main (gint Aargc, gchar *Aargv[])
     gtk_widget_destroy(Lwindow1);
   }
 
-  g_object_unref(GEraseCdrw);
-  g_object_unref(GGraver);
-  g_object_unref(GISOpetiteIcone);
-  g_object_unref(GpetiteGraver);
-  g_object_unref(GCDRWpetiteIcone);
-  g_object_unref(GCDRWIcone);
-  g_object_unref(GAudioIcone);
-  g_object_unref(GCDIcone);
-  g_object_unref(GFileImage);
-  g_object_unref(GFileIcone);
-  g_object_unref(GDirIcone);
-
+  free_all_images();
+  
   return EXIT_SUCCESS;
 }
 
